%define build_sys_rootcerts 1
%{?_without_sys_rootcerts: %{expand: %%global build_sys_rootcerts 0}}

%define name_orig   qca
%define qtcryptodir %{_libdir}/qca/crypto

Name:           qca2
Version:        2.2.1
Release:        %mkrel 9
License:        LGPLv2+
Summary:        Straightforward and cross-platform crypto API for Qt
Group:          System/Libraries
URL:            https://userbase.kde.org/QCA
# From kde support module
Source:         https://download.kde.org/stable/qca/%{version}/%{name_orig}-%{version}.tar.xz

BuildRequires:  qt4-devel >= 2:4.5
%if %{build_sys_rootcerts}
BuildRequires:  rootcerts
%endif
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(nss)
BuildRequires:  gnupg2
Obsoletes:      qca >= 2.0

%description
The QCA library provides an easy API for a range of cryptographic
features, including SSL/TLS, X.509 certificates, SASL, symmetric
ciphers, public key ciphers, hashes and much more.

Functionality is supplied via plugins. This is useful for avoiding
dependence on a particular crypto library and makes upgrading easier,
as there is no need to recompile your application when adding or
upgrading a crypto plugin. Also, by pushing crypto functionality into
plugins, applications are free of legal issues, such as export
regulation.

%files
%doc README COPYING INSTALL TODO
%{_bindir}/mozcerts
%{_bindir}/qcatool
%_mandir/man1/*

#------------------------------------------------------------------------------

%if ! %{build_sys_rootcerts}
%package -n %{name}-root-certificates
Summary:        Common root CA certificates for QCA
Group:          System/Libraries
Requires:       %{lib_name} = %{version}-%{release}

%description -n %{name}-root-certificates
Provides root Certificate Authority certificates for the QCA library.
These certificates are the same ones that are included in Mozilla.

%files -n %{name}-root-certificates
%dir %{_qt4_prefix}/share/qca
%dir %{_qt4_prefix}/share/qca/certs
%doc %{_qt4_prefix}/share/qca/certs/README
%{_qt4_prefix}/share/qca/certs/rootcerts.pem
%endif

#------------------------------------------------------------------------------
%define lib_major 2
%define lib_name  %mklibname %{name_orig} %{lib_major}

%package -n %{lib_name}
Summary:        Libraries for QCA
Group:          System/Libraries
%if %{build_sys_rootcerts}
Requires: rootcerts
Obsoletes:      %{name}-root-certificates
%else
Requires:       %{name}-root-certificates >= %{version}
%endif
Obsoletes:      %{mklibname qca 2 -d -s}
Obsoletes:      %{mklibname qca 2 -s}

%description -n %{lib_name}
Libraries for QCA.

%files -n %{lib_name}
%doc README COPYING INSTALL TODO
%dir %{qtcryptodir}
%{_qt4_libdir}/libqca.so.%{lib_major}*

#------------------------------------------------------------------------------

%define libdev %mklibname qca -d

%package -n %{libdev}
Summary:        Development files for QCA
Group:          Development/KDE and Qt
Requires:       %{lib_name} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{mklibname qca 2 -d} = %{version}-%{release}
Obsoletes:      %{mklibname qca 2 -d -s}
Obsoletes:      %{mklibname qca 2 -s}

%description -n %{libdev}
Development files for QCA.

%files -n %{libdev}
%{_libdir}/pkgconfig/qca2.pc
%{_qt4_prefix}/mkspecs/features/crypto.prf
%dir %{_qt4_includedir}/QtCrypto
%{_qt4_includedir}/QtCrypto/*
%{_qt4_libdir}/libqca.so
%dir %{_libdir}/cmake/Qca
%{_libdir}/cmake/Qca/*.cmake

#------------------------------------------------------------------------------

%package plugin-botan
Summary:        Botan plugin for QCA
Group:          Development/KDE and Qt
BuildRequires:  pkgconfig(botan-2)
Provides:       qca2-botan = %version

%description plugin-botan
This is a plugin to provide Botan capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-botan
%{qtcryptodir}/libqca-botan.*

#------------------------------------------------------------------------------

%package plugin-gnupg
Summary:        GnuPG plugin for QCA
Group:          Development/KDE and Qt
Provides:       qca2-gnupg = %version
Provides:       %{lib_name}-plugin-gnupg = %version
Obsoletes:      %{lib_name}-plugin-gnupg < %version
Provides:       qca2-plugin-gnupg-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-gnupg-%{_lib} < 2.0.0-5

%description plugin-gnupg
This is a plugin to provide GnuPG capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-gnupg
%{qtcryptodir}/libqca-gnupg.*

#------------------------------------------------------------------------------

%package plugin-openssl
Summary:        OpenSSL plugin for QCA
Group:          Development/KDE and Qt
BuildRequires:  pkgconfig(openssl)
Provides:       qca2-openssl = %version
Provides:       qca2-tls = %version
Provides:       qca2-plugin-openssl-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-openssl-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-openssl = %version
Obsoletes:      %{lib_name}-plugin-openssl < %version

%description plugin-openssl
This is a plugin to provide OpenSSL capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-openssl
%{qtcryptodir}/libqca-ossl.*

#------------------------------------------------------------------------------

%package plugin-pkcs11
Summary:        PKCS11 plugin for QCA
Group:          Development/KDE and Qt
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libpkcs11-helper-1)
Provides:       qca2-pkcs11 = %version
Provides:       qca2-plugin-pkcs11-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-pkcs11-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-pkcs11 = %version
Obsoletes:      %{lib_name}-plugin-pkcs11 < %version

%description plugin-pkcs11
This is a plugin to provide PKCS11 capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-pkcs11
%{qtcryptodir}/libqca-pkcs11.*

#------------------------------------------------------------------------------

%package plugin-cyrus-sasl
Summary:        Cyrus-sasl plugin for QCA
Group:          Development/KDE and Qt
BuildRequires:  pkgconfig(libsasl2)
Provides:       qca2-sasl = %version
Provides:       qca2-plugin-cyrus-sasl-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-cyrus-sasl-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-cyrus-sasl = %version
Obsoletes:      %{lib_name}-plugin-cyrus-sasl < %version

%description plugin-cyrus-sasl
This is a plugin to provide cyrus-sasl capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-cyrus-sasl
%{qtcryptodir}/libqca-cyrus-sasl.*

#------------------------------------------------------------------------------

%package plugin-logger
Summary:        Logger plugin for QCA
Group:          Development/KDE and Qt
Provides:       qca2-logger = %version
Provides:       qca2-plugin-logger-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-logger-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-logger = %version
Obsoletes:      %{lib_name}-plugin-logger < %version

%description plugin-logger
This is a plugin to provide logger capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-logger
%{qtcryptodir}/libqca-logger.*

#------------------------------------------------------------------------------

%package plugin-gcrypt
Summary:        Logger plugin for QCA
Group:          Development/KDE and Qt
Provides:       qca2-gcrypt = %version
Provides:       qca2-plugin-gcrypt-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-gcrypt-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-gcrypt = %version
Obsoletes:      %{lib_name}-plugin-gcrypt < %version

%description plugin-gcrypt
This is a plugin to provide gcrypt capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-gcrypt
%{qtcryptodir}/libqca-gcrypt.*

#------------------------------------------------------------------------------

%package plugin-nss
Summary:        Logger plugin for QCA
Group:          Development/KDE and Qt
Provides:       qca2-nss = %version
Provides:       qca2-plugin-nss-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-nss-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-nss = %version
Obsoletes:      %{lib_name}-plugin-nss < %version

%description plugin-nss
This is a plugin to provide nss capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-nss
%{qtcryptodir}/libqca-nss.*

#------------------------------------------------------------------------------

%package plugin-softstore
Summary:        Logger plugin for QCA
Group:          Development/KDE and Qt
Provides:       qca2-softstore = %version
Provides:       qca2-plugin-softstore-%{_lib} = %{version}-%{release}
Obsoletes:      qca2-plugin-softstore-%{_lib} < 2.0.0-5
Provides:       %{lib_name}-plugin-softstore = %version
Obsoletes:      %{lib_name}-plugin-softstore < %version

%description plugin-softstore
This is a plugin to provide softstore capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-softstore
%{qtcryptodir}/libqca-softstore.*

#------------------------------------------------------------------------------

%prep
%setup -q -n %{name_orig}-%{version}
%autopatch -p1

%build
%cmake_qt4 -DQT4_BUILD:BOOL=ON \
           -DQCA_FEATURE_INSTALL_DIR:PATH=%{_qt4_prefix}/mkspecs/features

%cmake_build

%install
%cmake_install


%changelog
* Sun Nov 08 2020 kekepower <kekepower> 2.2.1-9.mga8
+ Revision: 1643694
- Rebuild for Botan2, major 17

* Thu Oct 22 2020 daviddavid <daviddavid> 2.2.1-8.mga8
+ Revision: 1638597
- rebuild for new botan2 2.16.0

* Fri Jul 17 2020 daviddavid <daviddavid> 2.2.1-7.mga8
+ Revision: 1606727
- rebuild for new botan2 2.15.0

* Wed Feb 19 2020 umeabot <umeabot> 2.2.1-6.mga8
+ Revision: 1542999
- Mageia 8 Mass Rebuild

* Wed Jan 08 2020 daviddavid <daviddavid> 2.2.1-5.mga8
+ Revision: 1477284
- rebuild for new botan2 2.13.0
+ wally <wally>
- build with new cmake macros

* Thu Dec 05 2019 daviddavid <daviddavid> 2.2.1-4.mga8
+ Revision: 1464659
- rebuild for new botan 2.12.1

* Mon Jul 15 2019 daviddavid <daviddavid> 2.2.1-3.mga8
+ Revision: 1421549
- rebuild for new botan2 2.11.0

* Mon Jul 01 2019 daviddavid <daviddavid> 2.2.1-2.mga8
+ Revision: 1416903
- rebuild for new botan2 2.10.0

* Fri Apr 26 2019 daviddavid <daviddavid> 2.2.1-1.mga7
+ Revision: 1395567
- new version: 2.2.1

* Thu Apr 11 2019 daviddavid <daviddavid> 2.2.0-1.mga7
+ Revision: 1388334
- new version: 2.2.0
- enable botan support

* Sun Sep 23 2018 umeabot <umeabot> 2.1.3-3.mga7
+ Revision: 1300636
- Mageia 7 Mass Rebuild

* Fri Sep 15 2017 cjw <cjw> 2.1.3-2.mga7
+ Revision: 1153929
- patch1: fix build with openssl 1.1 (from qca-qt5)

* Sun Aug 27 2017 daviddavid <daviddavid> 2.1.3-1.mga7
+ Revision: 1148344
- new version: 2.1.3
- update URL and Source URL
- build against compat-openssl 1.0

* Thu Mar 03 2016 umeabot <umeabot> 2.1.1-2.mga6
+ Revision: 983965
- Rebuild for openssl

* Tue Jan 19 2016 neoclust <neoclust> 2.1.1-1.mga6
+ Revision: 925732
- New version 2.1.1

* Mon Sep 14 2015 fwang <fwang> 2.0.3-10.mga6
+ Revision: 879192
- rebuild for new libgcrypt

* Wed Oct 15 2014 umeabot <umeabot> 2.0.3-9.mga5
+ Revision: 743072
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.3-8.mga5
+ Revision: 688467
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 2.0.3-7.mga4
+ Revision: 533505
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 fwang <fwang> 2.0.3-6.mga4
+ Revision: 473654
- fix br
- rebuild for new sasl

* Tue Aug 27 2013 luigiwalser <luigiwalser> 2.0.3-5.mga4
+ Revision: 472087
- rebuild for cyrus-sasl

* Sun Jan 13 2013 umeabot <umeabot> 2.0.3-4.mga3
+ Revision: 379791
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Aug 11 2012 luigiwalser <luigiwalser> 2.0.3-3.mga3
+ Revision: 280684
- fix mkspec install (mikala)
- fix for gcc 4.7 (fedora)

* Mon Dec 26 2011 dmorgan <dmorgan> 2.0.3-2.mga2
+ Revision: 187974
- Rebuild against new qt4 and new include path

* Thu Jan 13 2011 mikala <mikala> 2.0.3-1.mga1
+ Revision: 16335
- imported package qca2

